import { z } from 'zod';
import { OAuth2Client } from '@badgateway/oauth2-client';
import { Connection } from '@prisma-app/client';
import { DataLayer } from './data-access';
import { oauthState } from './schemas';
import { IntegrationCredentialType, AuthToken } from './types';
type OAuthState = z.infer<typeof oauthState>;
type OAuthConfig = {
    SERVER: string;
    CLIENT_ID: string;
    CLIENT_SECRET: string;
    DISCOVERY_ENDPOINT?: string;
    REDIRECT_URI: string;
    SCOPES: string[];
    INTEGRATION_NAME: string;
    AUTH_TYPE: IntegrationCredentialType;
    AUTHORIZATION_ENDPOINT?: string;
    TOKEN_ENDPOINT?: string;
    REVOCATION_ENDPOINT?: string;
    AUTHENTICATION_METHOD?: string;
    EXTRA_AUTH_PARAMS?: {
        prompt?: string;
        access_type?: string;
        code_challenge?: string;
        code_challenge_method?: string;
    };
};
type APIKeyAuthConfig = {
    INTEGRATION_NAME: string;
    AUTH_TYPE: IntegrationCredentialType.API_KEY;
};
type AuthConfig = OAuthConfig | APIKeyAuthConfig;
export declare class IntegrationAuth {
    config: AuthConfig;
    client?: OAuth2Client;
    dataAccess: DataLayer;
    onConnectionCreated?: (connection: Connection, token: AuthToken) => Promise<any>;
    constructor({ config, dataAccess, onConnectionCreated, }: {
        config: AuthConfig;
        dataAccess: DataLayer;
        onConnectionCreated: (integration: Connection) => Promise<any>;
    });
    getClient(): OAuth2Client;
    getScopes(): string[];
    getRedirectUri(state: Pick<OAuthState, 'connectionId' | 'clientRedirectPath'>): Promise<string>;
    getTokenFromCodeRedirect(url: string): Promise<import("@badgateway/oauth2-client").OAuth2Token>;
    getStateFromRedirect(url: string): Promise<{
        name: string;
        connectionId: string;
        clientRedirectPath: string;
        previewRedirect?: string | undefined;
    }>;
    processCallback(url: string): Promise<void>;
    getAuthToken({ k_id }: {
        k_id: string;
    }): Promise<AuthToken>;
    private _refreshAuth;
    revokeAuth({ k_id }: {
        k_id: string;
    }): Promise<void>;
}
export {};
//# sourceMappingURL=authenticator.d.ts.map