import { Prisma, PrismaClient, Credential } from '@prisma-app/client';
import { FilterObject } from '../lib/query-builder/types';
import { prisma } from '../prisma/client';
import { RecordService } from '../service/service.record';
import { CredentialValue } from '../types';
export declare class DataLayer {
    db: PrismaClient;
    recordService: RecordService<typeof prisma>;
    constructor({ url }: {
        url: string;
        provider: string;
    });
    createConnection({ connection, credential, }: {
        connection: Prisma.ConnectionUncheckedCreateInput;
        credential: Omit<Prisma.CredentialUncheckedCreateInput, 'k_id'>;
    }): Promise<{
        id: string;
        name: string;
        createdAt: Date;
        updatedAt: Date | null;
        issues: string[];
        syncConfig: Prisma.JsonValue | null;
        connectionId: string;
        lastSyncAt: Date | null;
        subscriptionId: string | null;
    } & {
        credential: Credential;
    }>;
    deleteConnection({ connectionId }: {
        connectionId: string;
    }): Promise<{
        id: string;
        name: string;
        createdAt: Date;
        updatedAt: Date | null;
        issues: string[];
        syncConfig: Prisma.JsonValue | null;
        connectionId: string;
        lastSyncAt: Date | null;
        subscriptionId: string | null;
    }>;
    getConnection({ connectionId, name, }: {
        name: string;
        connectionId: string;
    }): Promise<{
        id: string;
        name: string;
        createdAt: Date;
        updatedAt: Date | null;
        issues: string[];
        syncConfig: Prisma.JsonValue | null;
        connectionId: string;
        lastSyncAt: Date | null;
        subscriptionId: string | null;
    } | null>;
    getConnectionsByIntegrationName({ name }: {
        name: string;
    }): Promise<{
        id: string;
        name: string;
        createdAt: Date;
        updatedAt: Date | null;
        issues: string[];
        syncConfig: Prisma.JsonValue | null;
        connectionId: string;
        lastSyncAt: Date | null;
        subscriptionId: string | null;
    }[]>;
    getAllConnections(): Promise<{
        name: string;
        connectionId: string;
    }[]>;
    getConnectionById({ k_id }: {
        k_id: string;
    }): Promise<{
        id: string;
        name: string;
        createdAt: Date;
        updatedAt: Date | null;
        issues: string[];
        syncConfig: Prisma.JsonValue | null;
        connectionId: string;
        lastSyncAt: Date | null;
        subscriptionId: string | null;
    } | null>;
    getCredentialsByConnection(k_id: string): Promise<{
        connection: {
            id: string;
            name: string;
            createdAt: Date;
            updatedAt: Date | null;
            issues: string[];
            syncConfig: Prisma.JsonValue | null;
            connectionId: string;
            lastSyncAt: Date | null;
            subscriptionId: string | null;
        };
    } & {
        id: string;
        type: string;
        k_id: string;
        value: Prisma.JsonValue;
        scope: string[];
    }>;
    updateConnectionCredential({ k_id, token, }: {
        k_id: string;
        token: CredentialValue;
    }): Promise<{
        id: string;
        type: string;
        k_id: string;
        value: Prisma.JsonValue;
        scope: string[];
    }>;
    createEntity({ connectionId, type, k_id, }: {
        k_id: string;
        type: string;
        connectionId: string;
    }): Promise<{
        id: string;
        type: string;
        createdAt: Date;
        updatedAt: Date | null;
        createdBy: string;
        k_id: string;
        lastSyncId: string | null;
    }>;
    getEntityById(entityId: string): Promise<{
        id: string;
        type: string;
        createdAt: Date;
        updatedAt: Date | null;
        createdBy: string;
        k_id: string;
        lastSyncId: string | null;
    }>;
    addPropertiesToEntity({ entityId, properties, }: {
        entityId: string;
        properties: Prisma.PropertyCreateInput[];
    }): Promise<{
        id: string;
        type: string;
        createdAt: Date;
        updatedAt: Date | null;
        createdBy: string;
        k_id: string;
        lastSyncId: string | null;
    }>;
    getEntityRecordsByConnectionAndType({ k_id, type, }: {
        k_id: string;
        type: string;
    }): Promise<({
        properties: {
            id: string;
            name: string;
            displayName: string;
            visible: boolean;
            config: Prisma.JsonValue | null;
            description: string | null;
            type: import("@prisma-app/client").$Enums.PropertyType;
            order: number;
            modifiable: boolean;
            parentId: string | null;
            entityId: string | null;
        }[];
        records: {
            id: string;
            entityId: string | null;
            createdAt: Date;
            updatedAt: Date | null;
            entityType: string;
            externalId: string | null;
            data: Prisma.JsonValue;
            source: string;
            status: import("@prisma-app/client").$Enums.RecordStatus;
            enrichmentStatus: import("@prisma-app/client").$Enums.RecordEnrichmentStatus;
            deletedAt: Date | null;
        }[];
    } & {
        id: string;
        type: string;
        createdAt: Date;
        updatedAt: Date | null;
        createdBy: string;
        k_id: string;
        lastSyncId: string | null;
    }) | null>;
    getEntityByConnectionAndType({ k_id, type, }: {
        k_id: string;
        type: string;
    }): Promise<{
        id: string;
        type: string;
        createdAt: Date;
        updatedAt: Date | null;
        createdBy: string;
        k_id: string;
        lastSyncId: string | null;
    } | null>;
    updateEntityLastSyncId({ entityId, syncId, }: {
        entityId: string;
        syncId: string;
    }): Promise<{
        id: string;
        type: string;
        createdAt: Date;
        updatedAt: Date | null;
        createdBy: string;
        k_id: string;
        lastSyncId: string | null;
    }>;
    deleteEntityById(entityId: string): Promise<{
        id: string;
        type: string;
        createdAt: Date;
        updatedAt: Date | null;
        createdBy: string;
        k_id: string;
        lastSyncId: string | null;
    }>;
    /**
     * Creates new records for a entity, or updates existing record 'data' if it already exists
     * @param entityId
     * @param records
     */
    mergeExternalRecordsForEntity({ entityId, records, }: {
        entityId: string;
        records: {
            externalId: string;
            data: Record<string, any>;
            entityType?: string;
        }[];
    }): Promise<[Prisma.BatchPayload | undefined, number | undefined] | undefined>;
    updateConnectionCredentials({ k_id, ...update }: Prisma.CredentialUpdateInput & {
        k_id: string;
    }): Promise<{
        id: string;
        type: string;
        k_id: string;
        value: Prisma.JsonValue;
        scope: string[];
    }>;
    getRecords<T extends string | number | symbol>({ entityType, k_id, filters, sort, }: {
        entityType: string;
        k_id: string;
        filters?: FilterObject<T>;
        sort?: string[];
    }): Promise<any>;
    getRecordByPropertyNameAndValues({ propertyName, propertValues, type, connectionId, }: {
        propertyName: string;
        propertValues: string[];
        type?: string;
        connectionId: string;
    }): Promise<{
        id: string;
        entityId: string | null;
        createdAt: Date;
        updatedAt: Date | null;
        entityType: string;
        externalId: string | null;
        data: Prisma.JsonValue;
        source: string;
        status: import("@prisma-app/client").$Enums.RecordStatus;
        enrichmentStatus: import("@prisma-app/client").$Enums.RecordEnrichmentStatus;
        deletedAt: Date | null;
    }[]>;
    getRecordByPropertyNameAndValue({ propertyName, propertyValue, type, connectionId, }: {
        propertyName: string;
        propertyValue: string;
        type: string;
        connectionId: string;
    }): Promise<{
        id: string;
        entityId: string | null;
        createdAt: Date;
        updatedAt: Date | null;
        entityType: string;
        externalId: string | null;
        data: Prisma.JsonValue;
        source: string;
        status: import("@prisma-app/client").$Enums.RecordStatus;
        enrichmentStatus: import("@prisma-app/client").$Enums.RecordEnrichmentStatus;
        deletedAt: Date | null;
    } | null>;
    getRecordsByPropertyName({ propertyName, connectionId, }: {
        propertyName: string;
        connectionId: string;
    }): Promise<{
        id: string;
        entityId: string | null;
        createdAt: Date;
        updatedAt: Date | null;
        entityType: string;
        externalId: string | null;
        data: Prisma.JsonValue;
        source: string;
        status: import("@prisma-app/client").$Enums.RecordStatus;
        enrichmentStatus: import("@prisma-app/client").$Enums.RecordEnrichmentStatus;
        deletedAt: Date | null;
    }[]>;
    setConnectionError({ k_id, error }: {
        k_id: string;
        error: string;
    }): Promise<{
        id: string;
        name: string;
        createdAt: Date;
        updatedAt: Date | null;
        issues: string[];
        syncConfig: Prisma.JsonValue | null;
        connectionId: string;
        lastSyncAt: Date | null;
        subscriptionId: string | null;
    }>;
    setConnectionSubscriptionId({ k_id, subscriptionId, }: {
        k_id: string;
        subscriptionId: string;
    }): Promise<{
        id: string;
        name: string;
        createdAt: Date;
        updatedAt: Date | null;
        issues: string[];
        syncConfig: Prisma.JsonValue | null;
        connectionId: string;
        lastSyncAt: Date | null;
        subscriptionId: string | null;
    }>;
    syncData({ connectionId, name, data, type, properties, lastSyncId, }: {
        name: string;
        properties: Prisma.PropertyCreateInput[];
        connectionId: string;
        data: any;
        type: string;
        lastSyncId?: string;
    }): Promise<void>;
    getConnectionsBySubscriptionId({ subscriptionId, }: {
        subscriptionId: string;
    }): Promise<{
        id: string;
        name: string;
        createdAt: Date;
        updatedAt: Date | null;
        issues: string[];
        syncConfig: Prisma.JsonValue | null;
        connectionId: string;
        lastSyncAt: Date | null;
        subscriptionId: string | null;
    }[]>;
}
//# sourceMappingURL=index.d.ts.map