import { IntegrationApi, IntegrationCredentialType, IntegrationEvent } from './types';
import { ZodSchema } from 'zod';
import { DataLayer } from './data-access';
import { IntegrationAuth } from './authenticator';
import { Connection } from '@prisma-app/client';
import { FilterObject } from './lib';
export type IntegrationConfig = {
    name: string;
    logoUrl: string;
    scopes?: string[];
    authType?: IntegrationCredentialType;
    authConnectionOptions?: ZodSchema;
    [key: string]: any;
};
export type CoreIntegrationPresets = {
    redirectURI: string;
};
/**
 * @params T - The type of the client that the integration provides
 */
export declare class Integration<T = unknown> {
    name: string;
    logoUrl: string;
    categories: string[];
    description: string;
    dataLayer?: DataLayer;
    config: Omit<IntegrationConfig, 'name' | 'logoUrl'> & {
        [key: string]: any;
    };
    availableScopes?: {
        key: string;
        description: string;
    }[];
    events: Record<string, IntegrationEvent<any>>;
    apis: Record<string, IntegrationApi<any>>;
    entityTypes: Record<string, string>;
    corePresets: CoreIntegrationPresets;
    constructor(config: IntegrationConfig);
    getConfig(): Omit<IntegrationConfig, "name" | "logoUrl"> & {
        [key: string]: any;
    };
    getClientZodSchema(): any;
    getCommentsForClientApis(): Record<string, {
        comment: string;
        doc?: string;
    }>;
    getBaseClient(): any;
    getApiClient(params: {
        connectionId: string;
    }): Promise<any>;
    getApi({ connectionId }: {
        connectionId: string;
    }): Promise<any>;
    _convertApiClientToSystemApis: () => Promise<void>;
    getAuthenticator(): IntegrationAuth;
    makeClient: (params: {
        connectionId: string;
    }) => Promise<T>;
    attachDataLayer({ dataLayer }: {
        dataLayer: DataLayer;
    }): void;
    registerApis(): {};
    getApis(): Record<string, IntegrationApi<any>>;
    registerEvents<T extends Integration>(): Record<string, IntegrationEvent<T>>;
    getEvents<T extends Integration>(): Record<string, IntegrationEvent<T>>;
    query<T extends string | number | symbol>(props: {
        connectionId: string;
        entityType: any;
        filters?: FilterObject<T>;
        sort?: string[];
    }): Promise<any>;
    getEvent(name: string): IntegrationEvent<any>;
    processWebhookRequest(params: {
        reqBody: any;
        event: string;
        connectionsBySubscriptionId: (subscriptionId: string) => Promise<Connection[]>;
    }): Promise<void>;
    triggerEvent<T = Record<string, any>>({ key, data, user, }: {
        key: string;
        data: T;
        user?: {
            connectionId: string;
            [key: string]: any;
        };
    }): Promise<import("inngest/types").SendEventOutput<{
        id: string;
    }>>;
    test({ connectionId, }: {
        connectionId: string;
    }): Promise<string | null>;
    onConnectionCreated({ connection, }: {
        connection: Connection;
    }): Promise<any>;
    onDisconnect({ connectionId, }: {
        connectionId: string;
    }): Promise<any>;
}
//# sourceMappingURL=integration.d.ts.map