import { z } from 'zod';
export declare const fullRepositorySchema: z.ZodObject<{
    allow_auto_merge: z.ZodOptional<z.ZodBoolean>;
    allow_forking: z.ZodOptional<z.ZodBoolean>;
    allow_merge_commit: z.ZodOptional<z.ZodBoolean>;
    allow_rebase_merge: z.ZodOptional<z.ZodBoolean>;
    allow_squash_merge: z.ZodOptional<z.ZodBoolean>;
    allow_update_branch: z.ZodOptional<z.ZodBoolean>;
    anonymous_access_enabled: z.ZodOptional<z.ZodBoolean>;
    archive_url: z.ZodString;
    archived: z.ZodBoolean;
    assignees_url: z.ZodString;
    blobs_url: z.ZodString;
    branches_url: z.ZodString;
    clone_url: z.ZodString;
    collaborators_url: z.ZodString;
    comments_url: z.ZodString;
    commits_url: z.ZodString;
    compare_url: z.ZodString;
    contents_url: z.ZodString;
    contributors_url: z.ZodString;
    created_at: z.ZodString;
    default_branch: z.ZodString;
    delete_branch_on_merge: z.ZodOptional<z.ZodBoolean>;
    deployments_url: z.ZodString;
    description: z.ZodNullable<z.ZodString>;
    disabled: z.ZodBoolean;
    downloads_url: z.ZodString;
    events_url: z.ZodString;
    fork: z.ZodBoolean;
    forks: z.ZodNumber;
    forks_count: z.ZodNumber;
    forks_url: z.ZodString;
    full_name: z.ZodString;
    git_commits_url: z.ZodString;
    git_refs_url: z.ZodString;
    git_tags_url: z.ZodString;
    git_url: z.ZodString;
    has_discussions: z.ZodBoolean;
    has_downloads: z.ZodBoolean;
    has_issues: z.ZodBoolean;
    has_pages: z.ZodBoolean;
    has_projects: z.ZodBoolean;
    has_wiki: z.ZodBoolean;
    homepage: z.ZodNullable<z.ZodString>;
    hooks_url: z.ZodString;
    html_url: z.ZodString;
    id: z.ZodNumber;
    is_template: z.ZodOptional<z.ZodBoolean>;
    issue_comment_url: z.ZodString;
    issue_events_url: z.ZodString;
    issues_url: z.ZodString;
    keys_url: z.ZodString;
    labels_url: z.ZodString;
    language: z.ZodNullable<z.ZodString>;
    languages_url: z.ZodString;
    master_branch: z.ZodOptional<z.ZodString>;
    merge_commit_message: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"PR_BODY">, z.ZodLiteral<"PR_TITLE">, z.ZodLiteral<"BLANK">]>>;
    merge_commit_title: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"PR_TITLE">, z.ZodLiteral<"MERGE_MESSAGE">]>>;
    merges_url: z.ZodString;
    milestones_url: z.ZodString;
    mirror_url: z.ZodNullable<z.ZodString>;
    name: z.ZodString;
    network_count: z.ZodNumber;
    node_id: z.ZodString;
    notifications_url: z.ZodString;
    open_issues: z.ZodNumber;
    open_issues_count: z.ZodNumber;
    permissions: z.ZodOptional<z.ZodObject<{
        admin: z.ZodBoolean;
        maintain: z.ZodOptional<z.ZodBoolean>;
        pull: z.ZodBoolean;
        push: z.ZodBoolean;
        triage: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        push: boolean;
        admin: boolean;
        pull: boolean;
        maintain?: boolean | undefined;
        triage?: boolean | undefined;
    }, {
        push: boolean;
        admin: boolean;
        pull: boolean;
        maintain?: boolean | undefined;
        triage?: boolean | undefined;
    }>>;
    private: z.ZodBoolean;
    pulls_url: z.ZodString;
    pushed_at: z.ZodString;
    releases_url: z.ZodString;
    size: z.ZodNumber;
    squash_merge_commit_message: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"PR_BODY">, z.ZodLiteral<"COMMIT_MESSAGES">, z.ZodLiteral<"BLANK">]>>;
    squash_merge_commit_title: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"PR_TITLE">, z.ZodLiteral<"COMMIT_OR_PR_TITLE">]>>;
    ssh_url: z.ZodString;
    stargazers_count: z.ZodNumber;
    stargazers_url: z.ZodString;
    statuses_url: z.ZodString;
    subscribers_count: z.ZodNumber;
    subscribers_url: z.ZodString;
    subscription_url: z.ZodString;
    svn_url: z.ZodString;
    tags_url: z.ZodString;
    teams_url: z.ZodString;
    temp_clone_token: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    topics: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    trees_url: z.ZodString;
    updated_at: z.ZodString;
    url: z.ZodString;
    use_squash_pr_title_as_default: z.ZodOptional<z.ZodBoolean>;
    visibility: z.ZodOptional<z.ZodString>;
    watchers: z.ZodNumber;
    watchers_count: z.ZodNumber;
    web_commit_signoff_required: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    archive_url: string;
    archived: boolean;
    assignees_url: string;
    blobs_url: string;
    branches_url: string;
    clone_url: string;
    collaborators_url: string;
    comments_url: string;
    commits_url: string;
    compare_url: string;
    contents_url: string;
    contributors_url: string;
    created_at: string;
    default_branch: string;
    deployments_url: string;
    description: string | null;
    disabled: boolean;
    downloads_url: string;
    events_url: string;
    fork: boolean;
    forks: number;
    forks_count: number;
    forks_url: string;
    full_name: string;
    git_commits_url: string;
    git_refs_url: string;
    git_tags_url: string;
    git_url: string;
    has_discussions: boolean;
    has_downloads: boolean;
    has_issues: boolean;
    has_pages: boolean;
    has_projects: boolean;
    has_wiki: boolean;
    homepage: string | null;
    hooks_url: string;
    html_url: string;
    id: number;
    issue_comment_url: string;
    issue_events_url: string;
    issues_url: string;
    keys_url: string;
    labels_url: string;
    language: string | null;
    languages_url: string;
    merges_url: string;
    milestones_url: string;
    mirror_url: string | null;
    name: string;
    network_count: number;
    node_id: string;
    notifications_url: string;
    open_issues: number;
    open_issues_count: number;
    private: boolean;
    pulls_url: string;
    pushed_at: string;
    releases_url: string;
    size: number;
    ssh_url: string;
    stargazers_count: number;
    stargazers_url: string;
    statuses_url: string;
    subscribers_count: number;
    subscribers_url: string;
    subscription_url: string;
    svn_url: string;
    tags_url: string;
    teams_url: string;
    trees_url: string;
    updated_at: string;
    url: string;
    watchers: number;
    watchers_count: number;
    allow_auto_merge?: boolean | undefined;
    allow_forking?: boolean | undefined;
    allow_merge_commit?: boolean | undefined;
    allow_rebase_merge?: boolean | undefined;
    allow_squash_merge?: boolean | undefined;
    allow_update_branch?: boolean | undefined;
    anonymous_access_enabled?: boolean | undefined;
    delete_branch_on_merge?: boolean | undefined;
    is_template?: boolean | undefined;
    master_branch?: string | undefined;
    merge_commit_message?: "PR_BODY" | "PR_TITLE" | "BLANK" | undefined;
    merge_commit_title?: "PR_TITLE" | "MERGE_MESSAGE" | undefined;
    permissions?: {
        push: boolean;
        admin: boolean;
        pull: boolean;
        maintain?: boolean | undefined;
        triage?: boolean | undefined;
    } | undefined;
    squash_merge_commit_message?: "PR_BODY" | "BLANK" | "COMMIT_MESSAGES" | undefined;
    squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
    temp_clone_token?: string | null | undefined;
    topics?: string[] | undefined;
    use_squash_pr_title_as_default?: boolean | undefined;
    visibility?: string | undefined;
    web_commit_signoff_required?: boolean | undefined;
}, {
    archive_url: string;
    archived: boolean;
    assignees_url: string;
    blobs_url: string;
    branches_url: string;
    clone_url: string;
    collaborators_url: string;
    comments_url: string;
    commits_url: string;
    compare_url: string;
    contents_url: string;
    contributors_url: string;
    created_at: string;
    default_branch: string;
    deployments_url: string;
    description: string | null;
    disabled: boolean;
    downloads_url: string;
    events_url: string;
    fork: boolean;
    forks: number;
    forks_count: number;
    forks_url: string;
    full_name: string;
    git_commits_url: string;
    git_refs_url: string;
    git_tags_url: string;
    git_url: string;
    has_discussions: boolean;
    has_downloads: boolean;
    has_issues: boolean;
    has_pages: boolean;
    has_projects: boolean;
    has_wiki: boolean;
    homepage: string | null;
    hooks_url: string;
    html_url: string;
    id: number;
    issue_comment_url: string;
    issue_events_url: string;
    issues_url: string;
    keys_url: string;
    labels_url: string;
    language: string | null;
    languages_url: string;
    merges_url: string;
    milestones_url: string;
    mirror_url: string | null;
    name: string;
    network_count: number;
    node_id: string;
    notifications_url: string;
    open_issues: number;
    open_issues_count: number;
    private: boolean;
    pulls_url: string;
    pushed_at: string;
    releases_url: string;
    size: number;
    ssh_url: string;
    stargazers_count: number;
    stargazers_url: string;
    statuses_url: string;
    subscribers_count: number;
    subscribers_url: string;
    subscription_url: string;
    svn_url: string;
    tags_url: string;
    teams_url: string;
    trees_url: string;
    updated_at: string;
    url: string;
    watchers: number;
    watchers_count: number;
    allow_auto_merge?: boolean | undefined;
    allow_forking?: boolean | undefined;
    allow_merge_commit?: boolean | undefined;
    allow_rebase_merge?: boolean | undefined;
    allow_squash_merge?: boolean | undefined;
    allow_update_branch?: boolean | undefined;
    anonymous_access_enabled?: boolean | undefined;
    delete_branch_on_merge?: boolean | undefined;
    is_template?: boolean | undefined;
    master_branch?: string | undefined;
    merge_commit_message?: "PR_BODY" | "PR_TITLE" | "BLANK" | undefined;
    merge_commit_title?: "PR_TITLE" | "MERGE_MESSAGE" | undefined;
    permissions?: {
        push: boolean;
        admin: boolean;
        pull: boolean;
        maintain?: boolean | undefined;
        triage?: boolean | undefined;
    } | undefined;
    squash_merge_commit_message?: "PR_BODY" | "BLANK" | "COMMIT_MESSAGES" | undefined;
    squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
    temp_clone_token?: string | null | undefined;
    topics?: string[] | undefined;
    use_squash_pr_title_as_default?: boolean | undefined;
    visibility?: string | undefined;
    web_commit_signoff_required?: boolean | undefined;
}>;
export declare const reposGetResponseSchema: z.ZodObject<{
    allow_auto_merge: z.ZodOptional<z.ZodBoolean>;
    allow_forking: z.ZodOptional<z.ZodBoolean>;
    allow_merge_commit: z.ZodOptional<z.ZodBoolean>;
    allow_rebase_merge: z.ZodOptional<z.ZodBoolean>;
    allow_squash_merge: z.ZodOptional<z.ZodBoolean>;
    allow_update_branch: z.ZodOptional<z.ZodBoolean>;
    anonymous_access_enabled: z.ZodOptional<z.ZodBoolean>;
    archive_url: z.ZodString;
    archived: z.ZodBoolean;
    assignees_url: z.ZodString;
    blobs_url: z.ZodString;
    branches_url: z.ZodString;
    clone_url: z.ZodString;
    collaborators_url: z.ZodString;
    comments_url: z.ZodString;
    commits_url: z.ZodString;
    compare_url: z.ZodString;
    contents_url: z.ZodString;
    contributors_url: z.ZodString;
    created_at: z.ZodString;
    default_branch: z.ZodString;
    delete_branch_on_merge: z.ZodOptional<z.ZodBoolean>;
    deployments_url: z.ZodString;
    description: z.ZodNullable<z.ZodString>;
    disabled: z.ZodBoolean;
    downloads_url: z.ZodString;
    events_url: z.ZodString;
    fork: z.ZodBoolean;
    forks: z.ZodNumber;
    forks_count: z.ZodNumber;
    forks_url: z.ZodString;
    full_name: z.ZodString;
    git_commits_url: z.ZodString;
    git_refs_url: z.ZodString;
    git_tags_url: z.ZodString;
    git_url: z.ZodString;
    has_discussions: z.ZodBoolean;
    has_downloads: z.ZodBoolean;
    has_issues: z.ZodBoolean;
    has_pages: z.ZodBoolean;
    has_projects: z.ZodBoolean;
    has_wiki: z.ZodBoolean;
    homepage: z.ZodNullable<z.ZodString>;
    hooks_url: z.ZodString;
    html_url: z.ZodString;
    id: z.ZodNumber;
    is_template: z.ZodOptional<z.ZodBoolean>;
    issue_comment_url: z.ZodString;
    issue_events_url: z.ZodString;
    issues_url: z.ZodString;
    keys_url: z.ZodString;
    labels_url: z.ZodString;
    language: z.ZodNullable<z.ZodString>;
    languages_url: z.ZodString;
    master_branch: z.ZodOptional<z.ZodString>;
    merge_commit_message: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"PR_BODY">, z.ZodLiteral<"PR_TITLE">, z.ZodLiteral<"BLANK">]>>;
    merge_commit_title: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"PR_TITLE">, z.ZodLiteral<"MERGE_MESSAGE">]>>;
    merges_url: z.ZodString;
    milestones_url: z.ZodString;
    mirror_url: z.ZodNullable<z.ZodString>;
    name: z.ZodString;
    network_count: z.ZodNumber;
    node_id: z.ZodString;
    notifications_url: z.ZodString;
    open_issues: z.ZodNumber;
    open_issues_count: z.ZodNumber;
    permissions: z.ZodOptional<z.ZodObject<{
        admin: z.ZodBoolean;
        maintain: z.ZodOptional<z.ZodBoolean>;
        pull: z.ZodBoolean;
        push: z.ZodBoolean;
        triage: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        push: boolean;
        admin: boolean;
        pull: boolean;
        maintain?: boolean | undefined;
        triage?: boolean | undefined;
    }, {
        push: boolean;
        admin: boolean;
        pull: boolean;
        maintain?: boolean | undefined;
        triage?: boolean | undefined;
    }>>;
    private: z.ZodBoolean;
    pulls_url: z.ZodString;
    pushed_at: z.ZodString;
    releases_url: z.ZodString;
    size: z.ZodNumber;
    squash_merge_commit_message: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"PR_BODY">, z.ZodLiteral<"COMMIT_MESSAGES">, z.ZodLiteral<"BLANK">]>>;
    squash_merge_commit_title: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"PR_TITLE">, z.ZodLiteral<"COMMIT_OR_PR_TITLE">]>>;
    ssh_url: z.ZodString;
    stargazers_count: z.ZodNumber;
    stargazers_url: z.ZodString;
    statuses_url: z.ZodString;
    subscribers_count: z.ZodNumber;
    subscribers_url: z.ZodString;
    subscription_url: z.ZodString;
    svn_url: z.ZodString;
    tags_url: z.ZodString;
    teams_url: z.ZodString;
    temp_clone_token: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    topics: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    trees_url: z.ZodString;
    updated_at: z.ZodString;
    url: z.ZodString;
    use_squash_pr_title_as_default: z.ZodOptional<z.ZodBoolean>;
    visibility: z.ZodOptional<z.ZodString>;
    watchers: z.ZodNumber;
    watchers_count: z.ZodNumber;
    web_commit_signoff_required: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    archive_url: string;
    archived: boolean;
    assignees_url: string;
    blobs_url: string;
    branches_url: string;
    clone_url: string;
    collaborators_url: string;
    comments_url: string;
    commits_url: string;
    compare_url: string;
    contents_url: string;
    contributors_url: string;
    created_at: string;
    default_branch: string;
    deployments_url: string;
    description: string | null;
    disabled: boolean;
    downloads_url: string;
    events_url: string;
    fork: boolean;
    forks: number;
    forks_count: number;
    forks_url: string;
    full_name: string;
    git_commits_url: string;
    git_refs_url: string;
    git_tags_url: string;
    git_url: string;
    has_discussions: boolean;
    has_downloads: boolean;
    has_issues: boolean;
    has_pages: boolean;
    has_projects: boolean;
    has_wiki: boolean;
    homepage: string | null;
    hooks_url: string;
    html_url: string;
    id: number;
    issue_comment_url: string;
    issue_events_url: string;
    issues_url: string;
    keys_url: string;
    labels_url: string;
    language: string | null;
    languages_url: string;
    merges_url: string;
    milestones_url: string;
    mirror_url: string | null;
    name: string;
    network_count: number;
    node_id: string;
    notifications_url: string;
    open_issues: number;
    open_issues_count: number;
    private: boolean;
    pulls_url: string;
    pushed_at: string;
    releases_url: string;
    size: number;
    ssh_url: string;
    stargazers_count: number;
    stargazers_url: string;
    statuses_url: string;
    subscribers_count: number;
    subscribers_url: string;
    subscription_url: string;
    svn_url: string;
    tags_url: string;
    teams_url: string;
    trees_url: string;
    updated_at: string;
    url: string;
    watchers: number;
    watchers_count: number;
    allow_auto_merge?: boolean | undefined;
    allow_forking?: boolean | undefined;
    allow_merge_commit?: boolean | undefined;
    allow_rebase_merge?: boolean | undefined;
    allow_squash_merge?: boolean | undefined;
    allow_update_branch?: boolean | undefined;
    anonymous_access_enabled?: boolean | undefined;
    delete_branch_on_merge?: boolean | undefined;
    is_template?: boolean | undefined;
    master_branch?: string | undefined;
    merge_commit_message?: "PR_BODY" | "PR_TITLE" | "BLANK" | undefined;
    merge_commit_title?: "PR_TITLE" | "MERGE_MESSAGE" | undefined;
    permissions?: {
        push: boolean;
        admin: boolean;
        pull: boolean;
        maintain?: boolean | undefined;
        triage?: boolean | undefined;
    } | undefined;
    squash_merge_commit_message?: "PR_BODY" | "BLANK" | "COMMIT_MESSAGES" | undefined;
    squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
    temp_clone_token?: string | null | undefined;
    topics?: string[] | undefined;
    use_squash_pr_title_as_default?: boolean | undefined;
    visibility?: string | undefined;
    web_commit_signoff_required?: boolean | undefined;
}, {
    archive_url: string;
    archived: boolean;
    assignees_url: string;
    blobs_url: string;
    branches_url: string;
    clone_url: string;
    collaborators_url: string;
    comments_url: string;
    commits_url: string;
    compare_url: string;
    contents_url: string;
    contributors_url: string;
    created_at: string;
    default_branch: string;
    deployments_url: string;
    description: string | null;
    disabled: boolean;
    downloads_url: string;
    events_url: string;
    fork: boolean;
    forks: number;
    forks_count: number;
    forks_url: string;
    full_name: string;
    git_commits_url: string;
    git_refs_url: string;
    git_tags_url: string;
    git_url: string;
    has_discussions: boolean;
    has_downloads: boolean;
    has_issues: boolean;
    has_pages: boolean;
    has_projects: boolean;
    has_wiki: boolean;
    homepage: string | null;
    hooks_url: string;
    html_url: string;
    id: number;
    issue_comment_url: string;
    issue_events_url: string;
    issues_url: string;
    keys_url: string;
    labels_url: string;
    language: string | null;
    languages_url: string;
    merges_url: string;
    milestones_url: string;
    mirror_url: string | null;
    name: string;
    network_count: number;
    node_id: string;
    notifications_url: string;
    open_issues: number;
    open_issues_count: number;
    private: boolean;
    pulls_url: string;
    pushed_at: string;
    releases_url: string;
    size: number;
    ssh_url: string;
    stargazers_count: number;
    stargazers_url: string;
    statuses_url: string;
    subscribers_count: number;
    subscribers_url: string;
    subscription_url: string;
    svn_url: string;
    tags_url: string;
    teams_url: string;
    trees_url: string;
    updated_at: string;
    url: string;
    watchers: number;
    watchers_count: number;
    allow_auto_merge?: boolean | undefined;
    allow_forking?: boolean | undefined;
    allow_merge_commit?: boolean | undefined;
    allow_rebase_merge?: boolean | undefined;
    allow_squash_merge?: boolean | undefined;
    allow_update_branch?: boolean | undefined;
    anonymous_access_enabled?: boolean | undefined;
    delete_branch_on_merge?: boolean | undefined;
    is_template?: boolean | undefined;
    master_branch?: string | undefined;
    merge_commit_message?: "PR_BODY" | "PR_TITLE" | "BLANK" | undefined;
    merge_commit_title?: "PR_TITLE" | "MERGE_MESSAGE" | undefined;
    permissions?: {
        push: boolean;
        admin: boolean;
        pull: boolean;
        maintain?: boolean | undefined;
        triage?: boolean | undefined;
    } | undefined;
    squash_merge_commit_message?: "PR_BODY" | "BLANK" | "COMMIT_MESSAGES" | undefined;
    squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
    temp_clone_token?: string | null | undefined;
    topics?: string[] | undefined;
    use_squash_pr_title_as_default?: boolean | undefined;
    visibility?: string | undefined;
    web_commit_signoff_required?: boolean | undefined;
}>;
export declare const reposListForOrgResponseSchema: z.ZodArray<z.ZodObject<{
    allow_auto_merge: z.ZodOptional<z.ZodBoolean>;
    allow_forking: z.ZodOptional<z.ZodBoolean>;
    allow_merge_commit: z.ZodOptional<z.ZodBoolean>;
    allow_rebase_merge: z.ZodOptional<z.ZodBoolean>;
    allow_squash_merge: z.ZodOptional<z.ZodBoolean>;
    allow_update_branch: z.ZodOptional<z.ZodBoolean>;
    anonymous_access_enabled: z.ZodOptional<z.ZodBoolean>;
    archive_url: z.ZodString;
    archived: z.ZodBoolean;
    assignees_url: z.ZodString;
    blobs_url: z.ZodString;
    branches_url: z.ZodString;
    clone_url: z.ZodString;
    collaborators_url: z.ZodString;
    comments_url: z.ZodString;
    commits_url: z.ZodString;
    compare_url: z.ZodString;
    contents_url: z.ZodString;
    contributors_url: z.ZodString;
    created_at: z.ZodString;
    default_branch: z.ZodString;
    delete_branch_on_merge: z.ZodOptional<z.ZodBoolean>;
    deployments_url: z.ZodString;
    description: z.ZodNullable<z.ZodString>;
    disabled: z.ZodBoolean;
    downloads_url: z.ZodString;
    events_url: z.ZodString;
    fork: z.ZodBoolean;
    forks: z.ZodNumber;
    forks_count: z.ZodNumber;
    forks_url: z.ZodString;
    full_name: z.ZodString;
    git_commits_url: z.ZodString;
    git_refs_url: z.ZodString;
    git_tags_url: z.ZodString;
    git_url: z.ZodString;
    has_discussions: z.ZodBoolean;
    has_downloads: z.ZodBoolean;
    has_issues: z.ZodBoolean;
    has_pages: z.ZodBoolean;
    has_projects: z.ZodBoolean;
    has_wiki: z.ZodBoolean;
    homepage: z.ZodNullable<z.ZodString>;
    hooks_url: z.ZodString;
    html_url: z.ZodString;
    id: z.ZodNumber;
    is_template: z.ZodOptional<z.ZodBoolean>;
    issue_comment_url: z.ZodString;
    issue_events_url: z.ZodString;
    issues_url: z.ZodString;
    keys_url: z.ZodString;
    labels_url: z.ZodString;
    language: z.ZodNullable<z.ZodString>;
    languages_url: z.ZodString;
    master_branch: z.ZodOptional<z.ZodString>;
    merge_commit_message: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"PR_BODY">, z.ZodLiteral<"PR_TITLE">, z.ZodLiteral<"BLANK">]>>;
    merge_commit_title: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"PR_TITLE">, z.ZodLiteral<"MERGE_MESSAGE">]>>;
    merges_url: z.ZodString;
    milestones_url: z.ZodString;
    mirror_url: z.ZodNullable<z.ZodString>;
    name: z.ZodString;
    network_count: z.ZodNumber;
    node_id: z.ZodString;
    notifications_url: z.ZodString;
    open_issues: z.ZodNumber;
    open_issues_count: z.ZodNumber;
    permissions: z.ZodOptional<z.ZodObject<{
        admin: z.ZodBoolean;
        maintain: z.ZodOptional<z.ZodBoolean>;
        pull: z.ZodBoolean;
        push: z.ZodBoolean;
        triage: z.ZodOptional<z.ZodBoolean>;
    }, "strip", z.ZodTypeAny, {
        push: boolean;
        admin: boolean;
        pull: boolean;
        maintain?: boolean | undefined;
        triage?: boolean | undefined;
    }, {
        push: boolean;
        admin: boolean;
        pull: boolean;
        maintain?: boolean | undefined;
        triage?: boolean | undefined;
    }>>;
    private: z.ZodBoolean;
    pulls_url: z.ZodString;
    pushed_at: z.ZodString;
    releases_url: z.ZodString;
    size: z.ZodNumber;
    squash_merge_commit_message: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"PR_BODY">, z.ZodLiteral<"COMMIT_MESSAGES">, z.ZodLiteral<"BLANK">]>>;
    squash_merge_commit_title: z.ZodOptional<z.ZodUnion<[z.ZodLiteral<"PR_TITLE">, z.ZodLiteral<"COMMIT_OR_PR_TITLE">]>>;
    ssh_url: z.ZodString;
    stargazers_count: z.ZodNumber;
    stargazers_url: z.ZodString;
    statuses_url: z.ZodString;
    subscribers_count: z.ZodNumber;
    subscribers_url: z.ZodString;
    subscription_url: z.ZodString;
    svn_url: z.ZodString;
    tags_url: z.ZodString;
    teams_url: z.ZodString;
    temp_clone_token: z.ZodNullable<z.ZodOptional<z.ZodString>>;
    topics: z.ZodOptional<z.ZodArray<z.ZodString, "many">>;
    trees_url: z.ZodString;
    updated_at: z.ZodString;
    url: z.ZodString;
    use_squash_pr_title_as_default: z.ZodOptional<z.ZodBoolean>;
    visibility: z.ZodOptional<z.ZodString>;
    watchers: z.ZodNumber;
    watchers_count: z.ZodNumber;
    web_commit_signoff_required: z.ZodOptional<z.ZodBoolean>;
}, "strip", z.ZodTypeAny, {
    archive_url: string;
    archived: boolean;
    assignees_url: string;
    blobs_url: string;
    branches_url: string;
    clone_url: string;
    collaborators_url: string;
    comments_url: string;
    commits_url: string;
    compare_url: string;
    contents_url: string;
    contributors_url: string;
    created_at: string;
    default_branch: string;
    deployments_url: string;
    description: string | null;
    disabled: boolean;
    downloads_url: string;
    events_url: string;
    fork: boolean;
    forks: number;
    forks_count: number;
    forks_url: string;
    full_name: string;
    git_commits_url: string;
    git_refs_url: string;
    git_tags_url: string;
    git_url: string;
    has_discussions: boolean;
    has_downloads: boolean;
    has_issues: boolean;
    has_pages: boolean;
    has_projects: boolean;
    has_wiki: boolean;
    homepage: string | null;
    hooks_url: string;
    html_url: string;
    id: number;
    issue_comment_url: string;
    issue_events_url: string;
    issues_url: string;
    keys_url: string;
    labels_url: string;
    language: string | null;
    languages_url: string;
    merges_url: string;
    milestones_url: string;
    mirror_url: string | null;
    name: string;
    network_count: number;
    node_id: string;
    notifications_url: string;
    open_issues: number;
    open_issues_count: number;
    private: boolean;
    pulls_url: string;
    pushed_at: string;
    releases_url: string;
    size: number;
    ssh_url: string;
    stargazers_count: number;
    stargazers_url: string;
    statuses_url: string;
    subscribers_count: number;
    subscribers_url: string;
    subscription_url: string;
    svn_url: string;
    tags_url: string;
    teams_url: string;
    trees_url: string;
    updated_at: string;
    url: string;
    watchers: number;
    watchers_count: number;
    allow_auto_merge?: boolean | undefined;
    allow_forking?: boolean | undefined;
    allow_merge_commit?: boolean | undefined;
    allow_rebase_merge?: boolean | undefined;
    allow_squash_merge?: boolean | undefined;
    allow_update_branch?: boolean | undefined;
    anonymous_access_enabled?: boolean | undefined;
    delete_branch_on_merge?: boolean | undefined;
    is_template?: boolean | undefined;
    master_branch?: string | undefined;
    merge_commit_message?: "PR_BODY" | "PR_TITLE" | "BLANK" | undefined;
    merge_commit_title?: "PR_TITLE" | "MERGE_MESSAGE" | undefined;
    permissions?: {
        push: boolean;
        admin: boolean;
        pull: boolean;
        maintain?: boolean | undefined;
        triage?: boolean | undefined;
    } | undefined;
    squash_merge_commit_message?: "PR_BODY" | "BLANK" | "COMMIT_MESSAGES" | undefined;
    squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
    temp_clone_token?: string | null | undefined;
    topics?: string[] | undefined;
    use_squash_pr_title_as_default?: boolean | undefined;
    visibility?: string | undefined;
    web_commit_signoff_required?: boolean | undefined;
}, {
    archive_url: string;
    archived: boolean;
    assignees_url: string;
    blobs_url: string;
    branches_url: string;
    clone_url: string;
    collaborators_url: string;
    comments_url: string;
    commits_url: string;
    compare_url: string;
    contents_url: string;
    contributors_url: string;
    created_at: string;
    default_branch: string;
    deployments_url: string;
    description: string | null;
    disabled: boolean;
    downloads_url: string;
    events_url: string;
    fork: boolean;
    forks: number;
    forks_count: number;
    forks_url: string;
    full_name: string;
    git_commits_url: string;
    git_refs_url: string;
    git_tags_url: string;
    git_url: string;
    has_discussions: boolean;
    has_downloads: boolean;
    has_issues: boolean;
    has_pages: boolean;
    has_projects: boolean;
    has_wiki: boolean;
    homepage: string | null;
    hooks_url: string;
    html_url: string;
    id: number;
    issue_comment_url: string;
    issue_events_url: string;
    issues_url: string;
    keys_url: string;
    labels_url: string;
    language: string | null;
    languages_url: string;
    merges_url: string;
    milestones_url: string;
    mirror_url: string | null;
    name: string;
    network_count: number;
    node_id: string;
    notifications_url: string;
    open_issues: number;
    open_issues_count: number;
    private: boolean;
    pulls_url: string;
    pushed_at: string;
    releases_url: string;
    size: number;
    ssh_url: string;
    stargazers_count: number;
    stargazers_url: string;
    statuses_url: string;
    subscribers_count: number;
    subscribers_url: string;
    subscription_url: string;
    svn_url: string;
    tags_url: string;
    teams_url: string;
    trees_url: string;
    updated_at: string;
    url: string;
    watchers: number;
    watchers_count: number;
    allow_auto_merge?: boolean | undefined;
    allow_forking?: boolean | undefined;
    allow_merge_commit?: boolean | undefined;
    allow_rebase_merge?: boolean | undefined;
    allow_squash_merge?: boolean | undefined;
    allow_update_branch?: boolean | undefined;
    anonymous_access_enabled?: boolean | undefined;
    delete_branch_on_merge?: boolean | undefined;
    is_template?: boolean | undefined;
    master_branch?: string | undefined;
    merge_commit_message?: "PR_BODY" | "PR_TITLE" | "BLANK" | undefined;
    merge_commit_title?: "PR_TITLE" | "MERGE_MESSAGE" | undefined;
    permissions?: {
        push: boolean;
        admin: boolean;
        pull: boolean;
        maintain?: boolean | undefined;
        triage?: boolean | undefined;
    } | undefined;
    squash_merge_commit_message?: "PR_BODY" | "BLANK" | "COMMIT_MESSAGES" | undefined;
    squash_merge_commit_title?: "PR_TITLE" | "COMMIT_OR_PR_TITLE" | undefined;
    temp_clone_token?: string | null | undefined;
    topics?: string[] | undefined;
    use_squash_pr_title_as_default?: boolean | undefined;
    visibility?: string | undefined;
    web_commit_signoff_required?: boolean | undefined;
}>, "many">;
//# sourceMappingURL=github.d.ts.map